==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Navigation/DefaultNavigation/ts/DefaultNavigation_ru.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ru">
<context>
    <name>DefaultNavigation</name>
    <message>
        <location filename="../DefaultNavigation.js" line="+46"/>
        <source>Graphics View</source>
        <translation>Графический вид</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Navigation</source>
        <translation>Навигация</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Zoom (Wheel Mouse)</source>
        <translation>Масштаб (колёсико мыши)</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Scroll (Trackpad, Multi-Touch Mouse)</source>
        <translation>Прокрутка (трекпад, мышь мультитач)</translation>
    </message>
</context>
<context>
    <name>GraphicsViewNavigation</name>
    <message>
        <location filename="../PreferencesPage.ui" line="+32"/>
        <source>Mouse wheel / two finger swipe:</source>
        <translation>Колёсико мыши/два пальца:</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Enable pan gesture</source>
        <translation>Включить жест панорамирования</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Reverse mouse wheel direction for zoom</source>
        <translation>Обратное направление колёсика мыши для увеличения</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Mouse wheel zoom factor:</source>
        <translation>Коэффициент масштабирования для колёсика мыши:</translation>
    </message>
    <message>
        <location line="-34"/>
        <source>Limit zoom and scroll to prevent overflows</source>
        <translation>Ограничить масштабирование и прокручивание чтобы предотвратить переполнение</translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Navigation/DefaultNavigation/ts/DefaultNavigation_ru.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ru">
<context>
    <name>DefaultNavigation</name>
    <message>
        <location filename="../DefaultNavigation.js" line="+47"/>
        <source>Graphics View</source>
        <translation>Графический вид</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Navigation</source>
        <translation>Навигация</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Zoom (Wheel Mouse)</source>
        <translation>Масштаб (колёсико мыши)</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Scroll (Trackpad, Multi-Touch Mouse)</source>
        <translation>Прокрутка (трекпад, мышь мультитач)</translation>
    </message>
</context>
<context>
    <name>GraphicsViewNavigation</name>
    <message>
        <location filename="../PreferencesPage.ui" line="+19"/>
        <source>Mouse wheel / two finger swipe:</source>
        <translation>Колёсико мыши/два пальца:</translation>
    </message>
    <message>
        <location line="+24"/>
        <source>Enable pan gesture</source>
        <translation>Включить жест панорамирования</translation>
    </message>
    <message>
        <location line="-10"/>
        <source>Reverse mouse wheel direction for zoom</source>
        <translation>Обратное направление колёсика мыши для увеличения</translation>
    </message>
    <message>
        <location line="-7"/>
        <source>Middle mouse button zoom factor:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+34"/>
        <source>Mouse wheel zoom factor:</source>
        <translation>Коэффициент масштабирования для колёсика мыши:</translation>
    </message>
    <message>
        <location line="+207"/>
        <source>Panning threshold (px):</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="-217"/>
        <source>Limit zoom and scroll to prevent overflows</source>
        <translation>Ограничить масштабирование и прокручивание чтобы предотвратить переполнение</translation>
    </message>
</context>
</TS>
